tw2.jqplugins.gritter
======================

:Author: Ralph Bean <ralph.bean@gmail.com>

.. comment: split here

.. _toscawidgets2 (tw2): http://toscawidgets.org/documentation/tw2.core/
.. _jQuery: http://jquery.com/

tw2.jqplugins.gritter is a `toscawidgets2 (tw2)`_ wrapper for the jquery gritter
plugin.

Links
-----

Original wrapped project is available `here
<http://boedesign.com/demos/gritter/>`_

Get the `source from github <http://github.com/ralphbean/tw2.jqplugins.gritter>`_.

`PyPI page <http://pypi.python.org/pypi/tw2.jqplugins.gritter>`_
and `bugs <http://github.com/ralphbean/tw2.jqplugins.gritter/issues/>`_
